==> qtjambi-script-5.15.6-sources.jar: io/qt/script/QScriptExtensionPlugin.java <==
package io.qt.script;


/**
 * <p>Abstract base for custom QScript extension plugins</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html">QScriptExtensionPlugin</a></p>
 */
public abstract class QScriptExtensionPlugin extends io.qt.core.QObject
    implements io.qt.script.QScriptExtensionInterface,
            io.qt.core.QFactoryInterface
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScriptExtensionPlugin.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QScriptExtensionPlugin {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public void initialize(java.lang.String key, io.qt.script.QScriptEngine engine){
            initialize_native_cref_QString_QScriptEngine_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), key, QtJambi_LibraryUtilities.internal.checkedNativeId(engine));
        }
        private native static void initialize_native_cref_QString_QScriptEngine_ptr(long __this__nativeId, java.lang.String key, long engine);
        
        
        @Override
        @io.qt.QtUninvokable
        public java.util.List<java.lang.String> keys(){
            return keys_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        private native static java.util.List<java.lang.String> keys_native_constfct(long __this__nativeId);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QScriptExtensionPlugin(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QScriptExtensionPlugin() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html#QScriptExtensionPlugin">QScriptExtensionPlugin::QScriptExtensionPlugin(QObject*)</a></p>
     */
    public QScriptExtensionPlugin(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
        if (parent != null) QtJambi_LibraryUtilities.internal.setCppOwnership(this);
    }
    
    private native static void initialize_native(QScriptExtensionPlugin instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html#setupPackage">QScriptExtensionPlugin::setupPackage(QString,QScriptEngine*)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.script.QScriptValue setupPackage(java.lang.String key, io.qt.script.QScriptEngine engine){
        return setupPackage_native_cref_QString_QScriptEngine_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), key, QtJambi_LibraryUtilities.internal.checkedNativeId(engine));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.script.QScriptValue setupPackage_native_cref_QString_QScriptEngine_ptr_constfct(long __this__nativeId, java.lang.String key, long engine);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html#initialize">QScriptExtensionInterface::initialize(QString,QScriptEngine*)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void initialize(java.lang.String key, io.qt.script.QScriptEngine engine);
    
    private native static void initialize_native_cref_QString_QScriptEngine_ptr(long __this__nativeId, java.lang.String key, long engine);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html#keys">QFactoryInterface::keys()const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract java.util.List<java.lang.String> keys();
    
    private native static java.util.List<java.lang.String> keys_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QScriptExtensionPlugin(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QScriptExtensionPlugin(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QScriptExtensionPlugin instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-script-5.15.12-sources.jar: io/qt/script/QScriptExtensionPlugin.java <==
package io.qt.script;


/**
 * <p>Abstract base for custom QScript extension plugins</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html">QScriptExtensionPlugin</a></p>
 */
public abstract class QScriptExtensionPlugin extends io.qt.core.QObject
    implements io.qt.script.QScriptExtensionInterface,
            io.qt.core.QFactoryInterface
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScriptExtensionPlugin.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QScriptExtensionPlugin {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public void initialize(java.lang.String key, io.qt.script.QScriptEngine engine){
            initialize_native_cref_QString_QScriptEngine_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), key, QtJambi_LibraryUtilities.internal.checkedNativeId(engine));
        }
        private native static void initialize_native_cref_QString_QScriptEngine_ptr(long __this__nativeId, java.lang.String key, long engine);
        
        
        @Override
        @io.qt.QtUninvokable
        public java.util.List<java.lang.String> keys(){
            return keys_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        private native static java.util.List<java.lang.String> keys_native_constfct(long __this__nativeId);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QScriptExtensionPlugin(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QScriptExtensionPlugin() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html#QScriptExtensionPlugin">QScriptExtensionPlugin::QScriptExtensionPlugin(QObject*)</a></p>
     */
    public QScriptExtensionPlugin(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
        if (parent != null) QtJambi_LibraryUtilities.internal.setCppOwnership(this);
    }
    
    private native static void initialize_native(QScriptExtensionPlugin instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html#setupPackage">QScriptExtensionPlugin::setupPackage(QString,QScriptEngine*)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.script.QScriptValue setupPackage(java.lang.String key, io.qt.script.QScriptEngine engine){
        return setupPackage_native_cref_QString_QScriptEngine_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), key, QtJambi_LibraryUtilities.internal.checkedNativeId(engine));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.script.QScriptValue setupPackage_native_cref_QString_QScriptEngine_ptr_constfct(long __this__nativeId, java.lang.String key, long engine);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html#initialize">QScriptExtensionInterface::initialize(QString,QScriptEngine*)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void initialize(java.lang.String key, io.qt.script.QScriptEngine engine);
    
    private native static void initialize_native_cref_QString_QScriptEngine_ptr(long __this__nativeId, java.lang.String key, long engine);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html#keys">QFactoryInterface::keys()const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract java.util.List<java.lang.String> keys();
    
    private native static java.util.List<java.lang.String> keys_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QScriptExtensionPlugin(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QScriptExtensionPlugin(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QScriptExtensionPlugin instance, QDeclarativeConstructor constructor);
    
}
